package
module
Version:
v0.0.0-...-327a2e5
Opens a new window with list of versions in this module.
Published: Oct 8, 2024
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
TTLMap map with expiring keys, keys expire after X amount of time from the time they were created or last accessed
Examples
Look into ttlmap_test.go
License
MIT Licence
Documentation
¶
func (m *TTLMap[K, T]) Put(k K, v T)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.